@@ -27,9 +27,9 @@ extern "C" {
 */
 #define MagickPackageName "ImageMagick"
 #define MagickCopyright  "Copyright (C) 1999-2007 ImageMagick Studio LLC"
-#define MagickLibVersion  0x633
-#define MagickLibVersionText  "6.3.3"
-#define MagickLibVersionNumber  6,3,3,5
+#define MagickLibVersion  0x635
+#define MagickLibVersionText  "6.3.5"
+#define MagickLibVersionNumber  6,3,5,9
 #if (QuantumDepth == 8)
 #define MagickQuantumDepth  "Q8"
 #define MagickQuantumRange  "255"
@@ -46,10 +46,15 @@ extern "C" {
 #define MagickQuantumDepth  "Q?"
 #define MagickQuantumRange  "?"
 #endif
-#define MagickReleaseDate  "04/04/07"
+#define MagickReleaseDate  "09/25/07"
+#if !defined(UseHDRI)
 #define MagickVersion MagickPackageName " " MagickLibVersionText " " \
-  MagickReleaseDate " " MagickQuantumDepth " " MagickHomeURL
-#define MagickHomeURL  "file:///usr/share/doc/ImageMagick-6.3.3/index.html"
+  MagickReleaseDate " " MagickQuantumDepth " http://www.imagemagick.org"
+#else
+#define MagickVersion MagickPackageName " " MagickLibVersionText " " \
+  MagickReleaseDate " " MagickQuantumDepth " HDRI http://www.imagemagick.org"
+#endif
+#define MagickHomeURL  "file:///usr/share/doc/ImageMagick-6.3.5/index.html"
 
 extern MagickExport char
   *GetMagickHomeURL(void);
